@@ -2,7 +2,8 @@
 
 use crate::{
     constants::{
-        Class, Type, DOMAIN_NAME_LABEL_MAX_LENGTH, DOMAIN_NAME_MAX_LENGTH, DOMAIN_NAME_MAX_POINTERS,
+        Class, RecordsSection, Type, DOMAIN_NAME_LABEL_MAX_LENGTH, DOMAIN_NAME_MAX_LENGTH,
+        DOMAIN_NAME_MAX_POINTERS,
     },
     message::{ClassValue, MessageType, OpCodeValue, RCodeValue, TypeValue},
 };
@@ -78,8 +79,8 @@ pub enum Error {
     #[error("buffer is not large enough: {0} bytes required")]
     BufferTooShort(usize),
 
-    #[error("malformed message: question is missing")]
-    MessageWithoutQuestion,
+    #[error("unexpected questions count {0}")]
+    BadQuestionsCount(usize),
 
     #[error("message type {0} is incompatible in this context")]
     BadMessageType(MessageType),
@@ -90,6 +91,12 @@ pub enum Error {
     #[error("message is truncated")]
     MessageTruncated,
 
+    #[error("message size exceeds 65535 bytes: {0}")]
+    MessageTooLong(usize),
+
+    #[error("section '{0}' offset is unknown")]
+    RecordsSectionOffsetUnknown(RecordsSection),
+
     #[error("message contains no records that answer the query")]
     NoAnswer,
 
